@@ -21,7 +21,7 @@ if [ -z "$DEPLOYTOOLS_VERSION" ]; then
   fi
 fi
 if [ -z "$MAVEN_VERSION" ]; then
-  MAVEN_VERSION=3.6.3
+  MAVEN_VERSION=3.8.6
 fi
 if [ -z "$PHANTOMJS_VERSION" ]; then
   PHANTOMJS_VERSION=2.1.1
@@ -35,6 +35,13 @@ fi
 if [ -z "$ACTIVEGATE_VERSION" ]; then
   ACTIVEGATE_VERSION=1.215.163
 fi
+if [ -z "$FLUTTER_VERSION" ]; then
+  FLUTTER_VERSION=3.0.4
+  FLUTTER_CSUM=be1dd08cb18504ddf6d435044fd5e162a4a420b8c48fe66a0002eefe6c58fa0a
+fi
+if [ -z "$LEIN_COMMIT" ]; then
+  LEIN_COMMIT=ef5ab97f058e8cb01e9c6a5a1cb6aa45c3b01d27 # 2.9.8
+fi
 
 # Make sure we get logging
 if ! grep cloud-init-output.log /etc/cloud/cloud.cfg.d/05_logging.cfg > /dev/null ; then
@@ -42,7 +49,7 @@ if ! grep cloud-init-output.log /etc/cloud/cloud.cfg.d/05_logging.cfg > /dev/nul
 fi
 
 install_lein() {
-  wget -O /usr/bin/lein https://raw.githubusercontent.com/technomancy/leiningen/stable/bin/lein
+  wget -O /usr/bin/lein https://codeberg.org/leiningen/leiningen/raw/commit/ef5ab97f058e8cb01e9c6a5a1cb6aa45c3b01d27/bin/lein
   chmod 755 /usr/bin/lein
 }
 install_phantomjs() {
@@ -56,19 +63,23 @@ install_yarn() {
   wget -O - https://yarnpkg.com/latest.tar.gz | tar --strip-components=1 -C /opt/yarn -xzv
 }
 install_cftools() {
-  if python --version | grep "Python 3" > /dev/null; then
-    curl -s https://s3.amazonaws.com/cloudformation-examples/aws-cfn-bootstrap-py3-latest.tar.gz | tar -xzvf -
+  if python --version | grep -q "Python 3"; then
+    wget -O - https://s3.amazonaws.com/cloudformation-examples/aws-cfn-bootstrap-py3-latest.tar.gz | tar -xzvf -
   else
-    curl -s https://s3.amazonaws.com/cloudformation-examples/aws-cfn-bootstrap-latest.tar.gz | tar -xzvf -
+    wget -O - https://s3.amazonaws.com/cloudformation-examples/aws-cfn-bootstrap-latest.tar.gz | tar -xzvf -
   fi
   cd aws-cfn-bootstrap-*
-  pip install .
+  pip install --disable-pip-version-check .
   cd ..
 }
 install_maven() {
-  wget -O - https://www-eu.apache.org/dist/maven/maven-3/$MAVEN_VERSION/binaries/apache-maven-$MAVEN_VERSION-bin.tar.gz | tar -xzvf - -C /opt/
+  source $(n-include common_tools.sh)
+  add_gpg_key 6A814B1F869C2BBEAB7CB7271A2A1C94BDE89688
+  gpg_safe_download https://downloads.apache.org/maven/maven-3/$MAVEN_VERSION/binaries/apache-maven-$MAVEN_VERSION-bin.tar.gz maven.tar.gz asc
+  tar -xzvf maven.tar.gz -C /opt/
+  rm maven.tar.gz
   ln -snf /opt/apache-maven-$MAVEN_VERSION /opt/maven
-  ln -snf  /opt/maven/bin/mvn /usr/bin/mvn
+  ln -snf /opt/maven/bin/mvn /usr/bin/mvn
 }
 install_nexus() {
   wget -O - https://sonatype-download.global.ssl.fastly.net/nexus/oss/nexus-$NEXUS_VERSION-bundle.tar.gz | tar -xzf - -C /opt/nexus
@@ -170,7 +181,7 @@ install_dynatrace_oneagent() {
 
 install_dynatrace_activegate() {
   # Requires secrets dynatrace.apikey and dt-root.cert.pem (from dynatrace web installation instructions) to be stored in secrets storage
-  wget  -O Dynatrace-ActiveGate-Linux-x86-$ACTIVEGATE_VERSION.sh \
+  wget -O Dynatrace-ActiveGate-Linux-x86-$ACTIVEGATE_VERSION.sh \
     "https://bmq38893.live.dynatrace.com/api/v1/deployment/installer/gateway/unix/latest?arch=x86&flavor=default" \
     --header="Authorization: Api-Token $(fetch-secrets.sh show dynatrace.apikey)"
 
@@ -194,4 +205,35 @@ enable_systemd_portforward() {
   checkmodule -M -m -o $MODULE $SOURCE
   semodule_package -o $PACKAGE -m $MODULE
   semodule -i $PACKAGE
-}
\ No newline at end of file
+}
+install_androidsdk() {
+  source $(n-include common_tools.sh)
+  safe_download https://dl.google.com/android/repository/commandlinetools-linux-8512546_latest.zip 2ccbda4302db862a28ada25aa7425d99dce9462046003c1714b059b5c47970d8 commandlinetools-linux_latest.zip
+  safe_download https://dl.google.com/android/repository/platform-tools_r33.0.2-linux.zip defcee9da1f22fe5c2324ec0edf612122f1c6ffe01a7b124191e07fcc74f8fff platform-tools-linux.zip
+  mkdir /opt/android
+  unzip -d /opt/android commandlinetools-linux_latest.zip
+  unzip -d /opt/android platform-tools-linux.zip
+  rm -f commandlinetools-linux_latest.zip platform-tools-linux.zip
+  mkdir /opt/android/cmdline-tools/latest
+  mv /opt/android/cmdline-tools/* /opt/android/cmdline-tools/latest ||:
+  cat > /etc/profile.d/android.sh << MARKER
+export PATH="\$PATH:/opt/android/platform-tools:/opt/android/cmdline-tools/latest/bin"
+MARKER
+  chmod 755 /etc/profile.d/android.sh
+  source /etc/profile.d/android.sh
+  yes | sdkmanager --sdk_root=/opt/android "platform-tools" "platforms;android-31" "platforms;android-30" "platforms;android-29" "emulator" "build-tools;33.0.0"
+  yes | sdkmanager --sdk_root=/opt/android --licenses
+}
+install_flutter() {
+  source $(n-include common_tools.sh)
+  safe_download https://storage.googleapis.com/flutter_infra_release/releases/stable/linux/flutter_linux_$FLUTTER_VERSION-stable.tar.xz $FLUTTER_CSUM flutter_linux-stable.tar.xz
+  tar -xJvf flutter_linux-stable.tar.xz -C /opt/
+  rm -f flutter_linux-stable.tar.xz
+  cat > /etc/profile.d/flutter.sh << MARKER
+export PATH="\$PATH:/opt/flutter/bin"
+MARKER
+  chmod 755 /etc/profile.d/flutter.sh
+  source /etc/profile.d/flutter.sh
+  flutter precache
+  yes | flutter doctor --android-licenses
+}
